Enum Request
#[non_exhaustive]pub enum Request<'a> {
Sync {},
GetRegistry {},
}wayland and Linux only.Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Sync
asynchronous roundtrip
The sync request asks the server to emit the ‘done’ event on the returned wl_callback object. Since requests are handled in-order and events are delivered in-order, this can be used as a barrier to ensure all previous requests and the resulting events have been handled.
The object returned by this request will be destroyed by the compositor after the callback is fired and as such the client must not attempt to use it after that point.
The callback_data passed in the callback is undefined and should be ignored.
GetRegistry
get global registry object
This request creates a registry object that allows the client to list and bind the global objects available from the compositor.
It should be noted that the server side resources consumed in response to a get_registry request can only be released when the client disconnects, not when the client side proxy is destroyed. Therefore, clients should invoke get_registry as infrequently as possible to avoid wasting memory.
Implementations